;;;
(deftemplate event_route (slot from)(slot to))
(deftemplate my_event_chain (slot InitialEvent)(slot FinalEvent))
(deftemplate reachable(slot from)(slot to))
(deftemplate detected_chain (slot InitialEvent)(slot intermediate)(slot FinalEvent))


(watch all)

;;;Rule 1: create all chain legs for events reachable from our initial event
(defrule from-start
   (my_event_chain (InitialEvent ?start))
   (event_route (from ?start)(to ?intermediate-location))
 => 
    (assert (reachable (from ?start)(to ?intermediate-location )))
    )

(require* EventExtraction)
;;;Get input function (Gets the initial event from the input)
(deffunction get-input()
	Get user input from console.
	(bind ?s (read))
	(return ?s))
	(printout t "Please insert the initial event : " crlf)
	(assert (my_event_chain (InitialEvent (get-input))(FinalEvent "accident"))
  )

;;;All the links are created here!
;;;Rule 2: create all chain legs for new events reachable from currently reachable events
(defrule to-intermediate1
    (reachable (from ?start)(to ?intermediate-location1))
    (event_route (from ?intermediate-location1)(to ?intermediate-location2))
=>
	(assert (reachable (from ?intermediate-location1)(to ?intermediate-location2))))
(run)

;;;Rule 3
;;;This rule finds event chains with only two event nodes from "Initial Event" to "accident".
(defrule to-destination1
    (my_event_chain (InitialEvent ?start)(FinalEvent ?destination))
	(reachable (from ?start)(to ?destination))
=>
      (printout t "                                           " crlf)
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "*                                                                                                                            " crlf)
      (printout t "* With the initial event: ( " ?start" ) the following event chain can be inferred:                                               " crlf)    
      (printout t "*                                                                                                                            " crlf)
      (printout t "* (" ?start   ")->("   ?destination")         " crlf)
      (printout t "*                                                                                                                            " crlf)   
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "                                                                                                                             " crlf)
   )
(run)
;;;Rule 4
;;;This rule finds event chains with three event nodes.
(defrule to-destination2
    (my_event_chain (InitialEvent ?start)(FinalEvent ?destination))
	(reachable (from ?start)(to ?intermediate-location1))
	(event_route (from ?intermediate-location1)(to ?destination))
=>
      (printout t "                                           " crlf)
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "*                                                                                                                            " crlf)
      (printout t "* With the initial event: ( " ?start" ) the following event chain can be inferred:                                               " crlf)    
      (printout t "*                                                                                                                            " crlf)  
      (printout t "* (" ?start   ")->("   ?intermediate-location1   ")-> ("   ?destination")         " crlf)
      (printout t "*                                                                                                                            " crlf)   
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "                                                                                                                             " crlf)
   )

(run)

;;;Rule 5
;;;This rule finds event chains with four event nodes.
(defrule to-destination3
    (my_event_chain (InitialEvent ?start)(FinalEvent ?destination))
	(reachable (from ?start)(to ?intermediate-location1))
	(event_route (from ?intermediate-location1)(to ?intermediate-location2))
    (event_route (from ?intermediate-location2)(to ?destination))
=>
      (printout t "                                           " crlf)
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "*                                                                                                                            " crlf)
      (printout t "* With the initial event: ( " ?start" ) the following event chain can be inferred:                                               " crlf)    
      (printout t "*                                                                                                                            " crlf)
      (printout t "* (" ?start   ")->("   ?intermediate-location1   ")->("   ?intermediate-location2   ")->("   ?destination")         " crlf)
      (printout t "*                                                                                                                            " crlf)   
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "                                                                                                                             " crlf)
   )

(run)

;;;Rule 6
;;;This rule finds event chains with five event nodes.
(defrule to-destination4
    (my_event_chain (InitialEvent ?start)(FinalEvent ?destination))
	(reachable (from ?start)(to ?intermediate-location1))
	(event_route (from ?intermediate-location1)(to ?intermediate-location2))
    (event_route (from ?intermediate-location2)(to ?intermediate-location3))
    (event_route (from ?intermediate-location3)(to ?destination))
=>
      (printout t "                                           " crlf)
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "*                                                                                                                            " crlf)
      (printout t "* With the initial event: ( " ?start" ) the following event chain can be inferred:                                               " crlf)    
      (printout t "*                                                                                                                            " crlf)  
      (printout t "* (" ?start   ")->("   ?intermediate-location1   ")->("   ?intermediate-location2   ")->("   ?intermediate-location3   ")->("   ?destination")         " crlf)
      (printout t "*                                                                                                                            " crlf)   
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "                                                                                                                             " crlf)
   )

(run)

;;;Rule 7
;;;This rule finds event chains with six event nodes.
(defrule to-destination5
    (my_event_chain (InitialEvent ?start)(FinalEvent ?destination))
	(reachable (from ?start)(to ?intermediate-location1))
	(event_route (from ?intermediate-location1)(to ?intermediate-location2))
    (event_route (from ?intermediate-location2)(to ?intermediate-location3))
    (event_route (from ?intermediate-location3)(to ?intermediate-location4))
    (event_route (from ?intermediate-location4)(to ?destination))
=>
      (printout t "                                           " crlf)
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "*                                                                                                                            " crlf)
      (printout t "* With the initial event: ( " ?start" ) the following event chain can be inferred:                                               " crlf)    
      (printout t "*                                                                                                                            " crlf)  
      (printout t "* (" ?start   ")->("   ?intermediate-location1   ")->("   ?intermediate-location2   ")->("   ?intermediate-location3   ")->("   ?intermediate-location4   ")->("   ?destination")         " crlf)
      (printout t "*                                                                                                                            " crlf)   
      (printout t "*****************************************************************************************************************************" crlf)
      (printout t "                                                                                                                             " crlf)
   )

;(facts)
(run)